<?php
/**
*
* @package acp
* @version $Id$
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* @package acp
*/
class acp_ate
{
	var $u_action;
	var $new_config = array();

	function main($id, $mode)
	{
		global $db, $user, $auth, $template, $cache, $ate, $table_prefix;
		global $config, $phpbb_root_path, $phpbb_admin_path, $phpEx;

		$user->add_lang(array('mods/ate', 'install', 'acp/database'));

		// Set up general vars
		$mode	= request_var('mode', '');
		$id	= request_var('id', 0);
		$submit	= isset($_POST['submit']) ? true : false;

		$this->tpl_name = 'acp_ate';
		$this->page_title = 'ACP_ATE';
		$form_key = 'acp_ate';

		add_form_key($form_key);

		switch ($mode)
		{
			case 'versioncheck':

				$info = $ate->check_latest_version(request_var('versioncheck_force', false), true);

				if ($info === false)
				{
					trigger_error('VERSIONCHECK_FAIL', E_USER_WARNING);
				}

				$info = explode("\n", $info);
				$latest_version = trim($info[0]);

				$announcement_url = trim($info[1]);
				$announcement_url = (strpos($announcement_url, '&amp;') === false) ? str_replace('&', '&amp;', $announcement_url) : $announcement_url;
				$update_link = append_sid($phpbb_root_path . 'install/index.' . $phpEx, 'mode=update');

				$up_to_date = (version_compare(str_replace('rc', 'RC', strtolower($config['ate_version'])), str_replace('rc', 'RC', strtolower($latest_version)), '<')) ? false : true;

				$template->assign_vars(array(
					'S_UP_TO_DATE'		=> $up_to_date,
					'S_VERSIONCHECK'	=> true,
					'U_ACTION'		=> $this->u_action,
					'U_VERSIONCHECK_FORCE' 	=> append_sid($this->u_action . '&amp;versioncheck_force=1'),

					'LATEST_VERSION'	=> $latest_version,
					'CURRENT_VERSION'	=> $config['ate_version'],

					'UPDATE_INSTRUCTIONS'	=> sprintf($user->lang['ATE_UPDATE_INSTRUCTIONS'], $announcement_url, $update_link),
				));
			break;

			case 'settings':

				$display_vars = array(
					'title'	=> 'ACP_ATE_SETTINGS',
					'vars'	=> array(
						'legend1'			=> 'ATE_SETTINGS',
						'ate_active'			=> array('lang' => 'ATE_ACTIVE',			'validate' => 'bool',	'type' => 'radio:yes_no', 'explain' => true),
						'ate_tpluse'			=> array('lang' => 'ATE_TEMPLATE_USE',			'validate' => 'bool',	'type' => 'radio:yes_no', 'explain' => true),
					)
				);

				$this->new_config = $config;
				$cfg_array = (isset($_REQUEST['config'])) ? utf8_normalize_nfc(request_var('config', array('' => ''), true)) : $this->new_config;
				$error = array();

				// We validate the complete config if whished
				validate_config_vars($display_vars['vars'], $cfg_array, $error);

				if ($submit && !check_form_key($form_key))
				{
					$error[] = $user->lang['FORM_INVALID'];
				}
				// Do not write values if there is an error
				if (sizeof($error))
				{
					$submit = false;
				}

				// We go through the display_vars to make sure no one is trying to set variables he/she is not allowed to...
				foreach ($display_vars['vars'] as $config_name => $null)
				{
					if (!isset($cfg_array[$config_name]) || strpos($config_name, 'legend') !== false)
					{
						continue;
					}

					$this->new_config[$config_name] = $config_value = $cfg_array[$config_name];

					if ($submit)
					{
						set_config($config_name, $config_value);
					}
				}

				if ($submit)
				{
					add_log('admin', 'LOG_ATE_SETTINGS');
					trigger_error($user->lang['ATE_SETTINGS_SAVED'] . adm_back_link($this->u_action));
				}

				$template->assign_vars(array(
					'S_SETTINGS'		=> true,
					'S_ERROR'		=> (sizeof($error)) ? true : false,
					'ERROR_MSG'		=> implode('<br />', $error),

					'U_ACTION'		=> $this->u_action
				));

				// Output relevant page
				foreach ($display_vars['vars'] as $config_key => $vars)
				{
					if (!is_array($vars) && strpos($config_key, 'legend') === false)
					{
						continue;
					}

					if (strpos($config_key, 'legend') !== false)
					{
						$template->assign_block_vars('options', array(
							'S_LEGEND'		=> true,
							'LEGEND'		=> (isset($user->lang[$vars])) ? $user->lang[$vars] : $vars)
						);

						continue;
					}

					$type = explode(':', $vars['type']);

					$l_explain = '';
					if ($vars['explain'] && isset($vars['lang_explain']))
					{
						$l_explain = (isset($user->lang[$vars['lang_explain']])) ? $user->lang[$vars['lang_explain']] : $vars['lang_explain'];
					}
					else if ($vars['explain'])
					{
						$l_explain = (isset($user->lang[$vars['lang'] . '_EXPLAIN'])) ? $user->lang[$vars['lang'] . '_EXPLAIN'] : '';
					}

					$content = build_cfg_template($type, $config_key, $this->new_config, $config_key, $vars);
		
					if (empty($content))
					{
						continue;
					}

					$template->assign_block_vars('options', array(
						'KEY'			=> $config_key,
						'TITLE'			=> (isset($user->lang[$vars['lang']])) ? $user->lang[$vars['lang']] : $vars['lang'],
						'S_EXPLAIN'		=> $vars['explain'],
						'TITLE_EXPLAIN'		=> $l_explain,
						'CONTENT'		=> $content,
					));

					unset($display_vars['vars'][$config_key]);
				}

			break;
/*
			// for backup option we need to check the user sql type
			// prablem for now lave it to next version
			// the xml backup working fine!
			case 'backup':

				$sql = "SELECT at.ate_id, at.theme_id, st.theme_name, st.theme_based, COUNT(ae.ate_id) AS num_of_elements, 1 AS num_of_sections
					FROM " . STYLES_ATE_THEME_TABLE . " at
					INNER JOIN " . STYLES_THEME_TABLE . " st
					ON at.theme_id = st.theme_id
					INNER JOIN " . STYLES_ATE_ELEMENTS_TABLE . " ae
					ON at.ate_id = ae.ate_id
					GROUP BY ae.element_group";
				$result = $db->sql_query($sql);

				$single_theme_data = array();
				$s_themes = '';
				while($theme_data = $db->sql_fetchrow($result))
				{
					if(!isset($single_theme_data[$theme_data['ate_id']]))
					{
						$single_theme_data[$theme_data['ate_id']] = $theme_data;
						$s_themes .= "<option value='{$theme_data['ate_id']}'>{$theme_data['theme_name']}</option>";
					}
					else
					{
						$single_theme_data[$theme_data['ate_id']]['num_of_elements'] += intval($theme_data['num_of_elements']);
						$single_theme_data[$theme_data['ate_id']]['num_of_sections'] += 1;
					}
				}
				$db->sql_freeresult($result);

				if(intval($id) > 0 && sizeof($single_theme_data[$id]))
				{
					$theme_data = $single_theme_data[$id];

					if($submit)
					{
						if($ate->backup($theme_data['ate_id'], $theme_data['theme_based'], request_var('backup_type', ''), request_var('backup_option', '')))
						{
							trigger_error($user->lang['ATE_THEME_BACKED_UP'] . adm_back_link($this->u_action));
						}
						else
						{
							trigger_error($user->lang['ATE_THEME_BACKED_UP_ERROR'] . adm_back_link($this->u_action), E_USER_WARNING);
						}
					}

					$template->assign_vars(array(
						'S_BACKUP_SELECTED'	=> true,
						'S_ATE_ID'		=> $theme_data['ate_id'],
						'THEME_NAME'		=> $theme_data['theme_name'],
						'THEME_BASED'		=> $theme_data['theme_based'],
						'THEME_ROWS_COUNT'	=> sprintf($user->lang['THEME_ROWS_COUNT'], $theme_data['num_of_elements'], $theme_data['num_of_sections']),
					));
				}

				$template->assign_vars(array(
					'S_BACKUP'		=> true,
					'S_THEMES'		=> $s_themes,
					'U_ACTION'		=> $this->u_action,
				));
			break;

			case 'restore':

				$sql = "SELECT at.ate_id, at.theme_id, st.theme_name
					FROM " . STYLES_ATE_THEME_TABLE . " at, " . STYLES_THEME_TABLE . " st
					WHERE at.theme_id = st.theme_id";
				$result = $db->sql_query($sql);

				$s_themes = '';
				$i = 0;
				while ($row = $db->sql_fetchrow($result))
				{
					$i++;
					$selected = $i == 1 ? " selected='selected'" : '';
					$s_themes .= "<option value='{$row['ate_id']}'{$selected}>{$row['theme_name']}</option>";
				}
				$db->sql_freeresult($result);

				$template->assign_vars(array(
					'S_RESTORE'		=> true,
					'S_THEMES'		=> $s_themes,
					'U_ACTION'		=> $this->u_action,
				));
			break;
*/
		}
	}
}

?>